OC.L10N.register(
    "groupfolders",
    {
    "Denied (Inherited permission)" : "Denegau (permiso heredau)",
    "Allowed (Inherited permission)" : "Permitiu (permiso heredau)",
    "Denied" : "Denegau",
    "Allowed" : "Permitiu",
    "Inherit permission" : "Heredar permiso",
    "Deny" : "Denegar",
    "Allow" : "Permitir",
    "Group" : "Grupo",
    "Read" : "Leyer",
    "Write" : "Escribir",
    "Create" : "Crear",
    "Delete" : "Borrar",
    "Share" : "Compartir",
    "You" : "Tú",
    "Remove access rule" : "Eliminar a regla d'acceso",
    "Add advanced permission rule" : "Anyadir regla de permiso abanzada",
    "Select a user or group" : "Estríe un usuario u grupo",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "Ye seguro que deseya eliminar \"{folderName}\" y toz os fichers que contiene? Ista operación no se puede desfer",
    "Delete \"{folderName}\"?" : "Borrar \"{folderName}\"?",
    "Folder name" : "Nombre de carpeta",
    "Quota" : "Quota",
    "Advanced Permissions" : "Permisos abanzaus",
    "None" : "Denguno"
},
"nplurals=2; plural=(n != 1);");
